from setuptools import setup

setup(name='stats_distribution',
      version='0.1',
      description='Gaussian distributions',
      author='Ajinkya Joshi',
      author_email='ajinkya.dj92@gmail.com',     
      packages=['stats_distribution'],
      zip_safe=False)
